Struct DeArray

struct DeArray<'i> { ... }

Type representing a TOML array, payload of the DeValue::Array variant

Implementations

impl<'i> DeArray<'i>

const fn new() -> Self

Constructs a new, empty DeArray.

This will not allocate until elements are pushed onto it.

fn push(self: &mut Self, value: Spanned<DeValue<'i>>)

Appends an element to the back of a collection.

Panics

Panics if the new capacity exceeds isize::MAX bytes.

impl Debug for DeArray<'_>

fn fmt(self: &Self, formatter: &mut Formatter<'_>) -> Result

impl Default for DeArray<'static>

fn default() -> Self

impl<'i> AsMut for DeArray<'i>

fn as_mut(self: &mut Self) -> &mut [Spanned<DeValue<'i>>]

impl<'i> AsRef for DeArray<'i>

fn as_ref(self: &Self) -> &[Spanned<DeValue<'i>>]

impl<'i> Borrow for DeArray<'i>

fn borrow(self: &Self) -> &[Spanned<DeValue<'i>>]

impl<'i> BorrowMut for DeArray<'i>

fn borrow_mut(self: &mut Self) -> &mut [Spanned<DeValue<'i>>]

impl<'i> Clone for DeArray<'i>

fn clone(self: &Self) -> DeArray<'i>

impl<'i> Deref for DeArray<'i>

fn deref(self: &Self) -> &[Spanned<DeValue<'i>>]

impl<'i> DerefMut for DeArray<'i>

fn deref_mut(self: &mut Self) -> &mut [Spanned<DeValue<'i>>]

impl<'i> Freeze for DeArray<'i>

impl<'i> FromIterator for DeArray<'i>

fn from_iter<I: IntoIterator<Item = Spanned<DeValue<'i>>>>(iter: I) -> Self

impl<'i> IntoIterator for DeArray<'i>

fn into_iter(self: Self) -> <Self as >::IntoIter

impl<'i> RefUnwindSafe for DeArray<'i>

impl<'i> Send for DeArray<'i>

impl<'i> Sync for DeArray<'i>

impl<'i> Unpin for DeArray<'i>

impl<'i> UnsafeUnpin for DeArray<'i>

impl<'i> UnwindSafe for DeArray<'i>

impl<'i, I: core::slice::SliceIndex<[serde_spanned::Spanned<crate::de::DeValue<'i>>]>> Index for DeArray<'i>

fn index(self: &Self, index: I) -> &<Self as >::Output

impl<P, T> Receiver for DeArray<'i>

impl<T> Any for DeArray<'i>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for DeArray<'i>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for DeArray<'i>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for DeArray<'i>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for DeArray<'i>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for DeArray<'i>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for DeArray<'i>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for DeArray<'i>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for DeArray<'i>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>