Type Alias DeTable

type DeTable = Map<Spanned<DeString<'i>>, Spanned<DeValue<'i>>>

Type representing a TOML table, payload of the Value::Table variant.

By default it entries are stored in lexicographic order of the keys. Enable the preserve_order feature to store entries in the order they appear in the source file.