[][src]Struct toml::map::OccupiedEntry

pub struct OccupiedEntry<'a> { /* fields omitted */ }

An occupied Entry. It is part of the Entry enum.

Methods

impl<'a> OccupiedEntry<'a>[src]

pub fn key(&self) -> &String[src]

Gets a reference to the key in the entry.

pub fn get(&self) -> &Value[src]

Gets a reference to the value in the entry.

pub fn get_mut(&mut self) -> &mut Value[src]

Gets a mutable reference to the value in the entry.

pub fn into_mut(self) -> &'a mut Value[src]

Converts the entry into a mutable reference to its value.

pub fn insert(&mut self, value: Value) -> Value[src]

Sets the value of the entry with the OccupiedEntry's key, and returns the entry's old value.

pub fn remove(self) -> Value[src]

Takes the value of the entry out of the map, and returns it.